/// <reference types="react" />
import { DecorationSet, ViewPlugin, ViewUpdate } from "@codemirror/view";
import { StateField, Extension } from "@codemirror/state";
import { SyntaxNode } from "@lezer/common";
import { ProjectionQuery } from "./query";
import { Diagnostic } from "@codemirror/lint";
export interface ProjectionProps {
    node: SyntaxNode;
    keyPath: (string | number)[];
    currentValue: any;
    setCode: (code: string) => void;
    fullCode: string;
    typings: any[];
    diagnosticErrors: Diagnostic[];
    cursorPositions: any[];
}
interface ProjectionBase {
    query: ProjectionQuery;
    projection: (props: ProjectionProps) => JSX.Element;
}
export interface ProjectionTooltip extends ProjectionBase {
    type: "tooltip";
    name: string;
}
export interface ProjectionFullTooltip extends ProjectionBase {
    type: "full-tooltip";
    name: string;
}
export interface ProjectionInline extends ProjectionBase {
    type: "inline";
    hasInternalState: boolean;
    mode: "replace" | "prefix" | "suffix" | "replace-multiline";
}
export interface ProjectionHighlight {
    type: "highlight";
    query: ProjectionQuery;
    class: string;
}
export declare type Projection = ProjectionInline | ProjectionTooltip | ProjectionFullTooltip | ProjectionHighlight;
export declare const getInUseRanges: (projectionsInUse: ProjectionMaterialization[]) => Set<`${number}-${number}`>;
export declare const projectionView: ViewPlugin<{
    decorations: DecorationSet;
    update(update: ViewUpdate): void;
}>;
declare type ProjectionMaterialization = {
    from: number;
    to: number;
    projection: Projection;
};
export interface ProjectionState {
    projectionsInUse: ProjectionMaterialization[];
}
export declare const projectionState: StateField<ProjectionState>;
export default function projectionPlugin(): Extension;
export {};
